@@ -5,11 +5,12 @@ from .crossbar import CrossbarConnection
 
 class Reswarm():
     def __init__(self, **options):
+        self.quiet = options.get("quiet", False)
         self.serial_number = os.environ.get('DEVICE_SERIAL_NUMBER', options.get("serial_number"))
         if self.serial_number == None:
             raise Exception("serial number is missing")
 
-        self.cb_connection = CrossbarConnection(self.serial_number)
+        self.cb_connection = CrossbarConnection(self.serial_number, self.quiet)
         self.cb_connection.start()
 
     def publish(self, topic: str, *args: list):
